(function (Drupal, once, drupalSettings) {
  'use strict';

  Drupal.behaviors.disclosure_menu = {
    attach: function (context, settings) {
      const rootMenuSelector = 'ul.menu.root-menu ';
      const submenuToggleSelector = 'button.menu-toggle';

      // Keyboard Navigation.
      once(
        'js-toggle-init',
        rootMenuSelector + submenuToggleSelector,
        context
      ).forEach((toggle) => {
        const submenuID = toggle.getAttribute('aria-controls');
        const submenu = document.getElementById(submenuID);
        // Hide button if there's no corresponding submenu.
        if (!submenu) {
          toggle.style.display = 'none';
        } else {
          const toggleSubmenu = () => {
            // Set whether the toggle is expanded.
            if (toggle.getAttribute('aria-expanded') === 'false') {
              toggle.setAttribute('aria-expanded', 'true');
            } else {
              toggle.setAttribute('aria-expanded', 'false');
            }
            // Toggle the submenu open or closed.
            submenu.classList.toggle('hide');
            submenu.style.display =
              submenu.style.display == 'none' ? '' : 'none';
          };

          const hideSubmenu = (event) => {
            if (!submenu.contains(event.relatedTarget)) {
              // Set the toggle to not expanded.
              toggle.setAttribute('aria-expanded', 'false');
              // Hide the submenu
              submenu.classList.add('hide');
              submenu.style.display = 'none';
            }
          };

          // On toggle button click, toggle the submenu.
          toggle.addEventListener('click', toggleSubmenu);

          // Close submenu after tabbing past it.
          submenu.addEventListener('focusout', hideSubmenu);
          toggle.addEventListener('blur', hideSubmenu);
        }
      });
    },
    detach: function (context, settings) {},
  };
})(Drupal, once, drupalSettings);
