(function (Drupal, once, drupalSettings) {
  'use strict';

  Drupal.behaviors.disclosure_menu_hover = {
    attach: function (context, settings) {
      const rootMenuSelector = 'ul.menu.root-menu ';
      const menuLinkSelector = 'li.menu-item > a[data-submenu-id]';
      const showIntentDelay =
        drupalSettings['disclosureMenu']['hoverShowDelay'];
      const hideIntentDelay =
        drupalSettings['disclosureMenu']['hoverHideDelay'];

      // Hover Navigation.
      once(
        'js-hover-init',
        rootMenuSelector + menuLinkSelector,
        context
      ).forEach((link) => {
        const submenuID = link.getAttribute('data-submenu-id');
        const submenu = document.getElementById(submenuID);
        if (!submenu) return;

        // Set timeout to hide submenu.
        const startHideIntent = () => {
          const hideIntent = setTimeout(() => {
            submenu.classList.add('hide');
            submenu.style.display = 'none';
          }, hideIntentDelay);
          submenu.setAttribute('data-hide-intent', hideIntent);
        };

        // Remove timeout to hide submenu, if it exists.
        const endHideIntent = () => {
          const hideIntent = submenu.getAttribute('data-hide-intent');
          if (hideIntent) {
            clearTimeout(hideIntent);
            submenu.removeAttribute('data-hide-intent');
          }
        };

        // Set timeout to show submenu.
        const startShowIntent = () => {
          const showIntent = setTimeout(() => {
            submenu.classList.remove('hide');
            submenu.style.display = '';
          }, showIntentDelay);
          submenu.setAttribute('data-show-intent', showIntent);
        };

        // Remove timeout to show submenu, if it exists.
        const endShowIntent = () => {
          const showIntent = submenu.getAttribute('data-show-intent');
          if (showIntent) {
            clearTimeout(showIntent);
            submenu.removeAttribute('data-show-intent');
          }
        };

        // When hover over parent link, show submenu.
        link.addEventListener('pointerover', () => {
          endHideIntent();
          startShowIntent();
        });

        // When not hovering over parent link, hide submenu.
        link.addEventListener('pointerout', () => {
          endShowIntent();
          startHideIntent();
        });

        // When hovering over submenu, keep showing submenu.
        submenu.addEventListener('pointerover', endHideIntent);

        // When not hovering over submenu, hide submenu.
        submenu.addEventListener('pointerout', startHideIntent);
      });
    },
    detach: function (context, settings) {},
  };
})(Drupal, once, drupalSettings);
